OffsetFrame

Struct OffsetFrame 

pub struct OffsetFrame { /* private fields */ }
A FLAC stream’s Frame, with samples that are offset such that the first frame has a frame/sample offset of 0 and the others follow suit.

This is meant to be created once per Track, and then updated for all the frames making up that track.

Implementations

Source

impl OffsetFrame

pub fn process(&mut self, packet: Packet) -> Result<Vec<u8>>

Processes a FLAC frame by rewriting its sample/frame offset and CRC checksums, and emits that frame in an updated byte buffer.

Returns a byte buffer containing the updated frame.