Track

Struct Track 

pub struct Track {
    pub number: u32,
    pub start_ts: u64,
    pub end_ts: u64,
    pub tags: Vec<Tag>,
    pub visuals: Vec<Visual>,
    /* private fields */
}
Metadata identifying a track in a FLAC file that has an embedded CUE sheet.

Fields

number: u32start_ts: u64end_ts: u64tags: Vec<Tag>visuals: Vec<Visual>

Implementations

Source

impl Track

pub fn from_tags( streaminfo: &StreamInfo, cue: &Cue, end_ts: u64, tags: &[Tag], visuals: &[Visual], ) -> Self

Create a Track from a file’s embedded FLAC&vorbis comments and CUE sheet.

pub fn tag_value(&self, name: &str) -> Option<&Value>

Return the tag value for a given tag name.

pub fn pathname(&self) -> PathBuf

Return the output pathname for a track.

pub fn write_metadata<S: Write>( &self, total_samples: u64, metadata_padding: u32, to: S, ) -> Result<()>

Write a track’s STREAM metadata blocks - first STREAMINFO, then the remainder containing pictures and vorbis comments.

pub fn write_audio<S: Write>(&self, from: &mut FlacReader, to: S) -> Result<u64>

Write a STREAM’s FRAME sequence, containing compressed audio samples. Returns the number of samples actually processed.