pub struct Track {
pub number: u32,
pub start_ts: u64,
pub end_ts: u64,
pub tags: Vec<Tag>,
pub visuals: Vec<Visual>,
/* private fields */
}Expand description
Metadata identifying a track in a FLAC file that has an embedded CUE sheet.
Fields
number: u32start_ts: u64end_ts: u64visuals: Vec<Visual>Implementations
Sourceimpl Track
impl Track
Create a Track from a file’s embedded FLAC&vorbis comments and CUE sheet.
Sourcepub fn tag_value(&self, name: &str) -> Option<&Value>
pub fn tag_value(&self, name: &str) -> Option<&Value>
Return the tag value for a given tag name.
Sourcepub fn write_metadata<S: Write>(
&self,
total_samples: u64,
metadata_padding: u32,
to: S,
) -> Result<()>
pub fn write_metadata<S: Write>( &self, total_samples: u64, metadata_padding: u32, to: S, ) -> Result<()>
Write a track’s STREAM metadata blocks - first STREAMINFO, then the remainder containing pictures and vorbis comments.
Sourcepub fn write_audio<S: Write>(&self, from: &mut FlacReader, to: S) -> Result<u64>
pub fn write_audio<S: Write>(&self, from: &mut FlacReader, to: S) -> Result<u64>
Write a STREAM’s FRAME sequence, containing compressed audio samples. Returns the number of samples actually processed.